@@ -1,5 +1,5 @@
 /******************************************************************************
-    (c) 2000-2005 Patrick Caulfield                 patrick@debian.org
+    (c) 2000-2008 Christine Caulfield                 christine.caulfield@googlemail.com
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -85,7 +85,7 @@ LATConnection::LATConnection(int _num, unsigned char *buf, int len,
     next_session = 1;
     highest_session = 1;
     max_window_size = msg->exqueued+1;
-    max_window_size = 1; // PJC All we can manage
+    max_window_size = 1; // All we can manage
     window_size = 0;
     lat_eco = msg->latver_eco;
     max_slots_per_packet = 4;
@@ -331,7 +331,7 @@ bool LATConnection::process_session_cmd(unsigned char *buf, int len,
 							   slotcmd->remote_session,
 							   newsessionnum,
 							   (*master_conn)->eightbitclean);
-			    if (newsession->new_session(remnode, "","",
+			    if (newsession->new_session(remnode, (char*)"", (char*)"",
 							credits) == -1)
 			    {
 				newsession->send_disabled_message();
@@ -392,7 +392,7 @@ bool LATConnection::process_session_cmd(unsigned char *buf, int len,
 							   cmd, uid, gid,
 							   slotcmd->remote_session,
 							   newsessionnum, false);
-			    if (newsession->new_session(remnode, "", (char *)portname,
+			    if (newsession->new_session(remnode, (char*)"", (char *)portname,
 							credits) == -1)
 			    {
 				newsession->send_disabled_message();
@@ -852,7 +852,7 @@ void LATConnection::circuit_timer(void)
     send_ack = false;
 
     //  Send a pending data message (if we can)
-    if (!pending_data.empty() && window_size < max_window_size)
+    if (!pending_data.empty() && window_size <= max_window_size)
     {
         // Send the top message
         pending_msg &msg(pending_data.front());
@@ -1197,7 +1197,7 @@ void LATConnection::got_status(unsigned char *node, LAT_StatusEntry *entry)
 	s->show_status(node, entry);
     }
 
-// TODO: mark this session (connection?) as waiting for connect so 
+// TODO: mark this session (connection?) as waiting for connect so
 // that, if the user quits, we can tell the server. (TODODO: what message ??)
 }
 
@@ -1303,7 +1303,7 @@ int LATConnection::got_connect_ack(unsigned char *buf)
     connecting = false;
 
     max_window_size = reply->exqueued+1;
-    max_window_size = 1; // PJC All we can manage
+    max_window_size = 1; // All we can manage
     window_size = 0;
 //    need_ack = false;
 
@@ -1382,13 +1382,14 @@ int LATConnection::pending_msg::send(int interface, unsigned char *macaddr)
     return LATServer::Instance()->send_message(buf, len, interface, macaddr);
 }
 
-int LATConnection::num_clients()
+unsigned int LATConnection::num_clients()
 {
     unsigned int i;
-    int num = 0;
+    unsigned int num = 0;
 
     for (i=1; i<=highest_session; i++)
-	if (sessions[i]) num++;
+	if (sessions[i])
+		num++;
 
     return num;
 }
